@@ -32,7 +32,7 @@ def _default_condition(*_: Any, **__: Any) -> bool:
 class PredicatesList:
     """Class for a list of predicate functions (lambda condition) and original code functions"""
 
-    __slots__ = ["_list", "_default_func_tuple"]
+    __slots__ = "_list", "_default_func_tuple"
 
     def __init__(self) -> None:
         self._list: CallableList = []
